<?php

class AggDatabase
{
	protected $db;
	protected $olxCredentialsTable, $olxCategoriesTable, $olxAttributesTable, $olxOptionsTable, $wcOlxAttributeTable, $wcOlxOptionTable, $olxCityTable;

	/**
	 * AggDatabase constructor.
	 */
	public function __construct()
	{
		global $wpdb;
		$this->db = $wpdb;
		$this->olxCredentialsTable = $wpdb->prefix . 'agg_olx_credentials';
		$this->olxCategoriesTable  = $wpdb->prefix . 'agg_olx_categories';
		$this->olxAttributesTable  = $wpdb->prefix . 'agg_olx_attributes';
		$this->olxOptionsTable     = $wpdb->prefix . 'agg_olx_options';
		$this->wcOlxAttributeTable = $wpdb->prefix . 'agg_wc_olx_attribute';
		$this->wcOlxOptionTable    = $wpdb->prefix . 'agg_wc_olx_option';
		$this->olxCityTable        = $wpdb->prefix . 'agg_olx_cities';
	}

//	/**
//	 * Call function to create agg_credentials table
//	 */
//	public function createOlxCredentialsTable()
//	{
//		add_action( 'admin_init', array($this, 'createOlxCredentialsTableSQL'));
//	}
//
//	/**
//	 * Call function to create agg_categories table
//	 */
//	public function createOlxCategoriesTable()
//	{
//		add_action( 'admin_init', array($this, 'createOlxCategoriesTableSQL'));
//	}

	/**
	 * Create All Plugin Tables
	 */
	public function createAllTables()
	{
		$this->createOlxCredentialsTable();
		$this->createOlxCategoriesTable();
		$this->createOlxAttributesTable();
		$this->createOlxOptionsTable();
		$this->createWcOlxAttributeTable();
		$this->createWcOlxOptionTable();
		$this->createOlxCityTable();
	}

	/**
	 * Delete All Plugin Tables
	 */
	public function deleteAllTables()
	{
		$this->dropOlxCredentialsTable();
		$this->dropOlxCategoriesTable();
		$this->dropOlxAttributesTable();
		$this->dropOlxOptionsTable();
		$this->dropWcOlxAttributeTable();
		$this->dropWcOlxOptionTable();
		$this->dropOlxCityTable();
	}

	/******* Create tables section *******/

	public function createOlxCredentialsTable()
	{
		$charset_collate = $this->db->get_charset_collate();
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$table_name = $this->olxCredentialsTable;
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
				id INTEGER NOT NULL AUTO_INCREMENT,
				client_id TEXT NOT NULL,
				client_token TEXT NOT NULL,
				PRIMARY KEY (id)
				) $charset_collate;";
		dbDelta($sql);
	}

	public function dropOlxCredentialsTable()
	{
		$table_name = $this->olxCredentialsTable;
		$sql = "DROP TABLE IF EXISTS $table_name";
		$this->db->query($sql);
	}

	public function createOlxCategoriesTable()
	{
		$charset_collate = $this->db->get_charset_collate();
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$table_name = $this->olxCategoriesTable;
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
				id INTEGER NOT NULL AUTO_INCREMENT,
				name VARCHAR (191) NOT NULL,
				olx_id INTEGER NOT NULL,
				parent_id INTEGER DEFAULT NULL,
				mapped_id INTEGER DEFAULT NULL,
				last BOOLEAN DEFAULT 0,
				PRIMARY KEY (id),
				FOREIGN KEY (parent_id) REFERENCES $table_name (id)
				) $charset_collate;";
		dbDelta($sql);
	}

	public function dropOlxCategoriesTable()
	{
		$table_name = $this->olxCategoriesTable;
		$sql = "DROP TABLE IF EXISTS $table_name";
		$this->db->query($sql);
	}

	public function createOlxAttributesTable()
	{
		$charset_collate = $this->db->get_charset_collate();
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$table_name = $this->olxAttributesTable;
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id INTEGER NOT NULL AUTO_INCREMENT,
			name VARCHAR (191) NOT NULL,
			type VARCHAR (191) NOT NULL,
			field VARCHAR (191) NULL,
			required BOOLEAN DEFAULT 0,
			category_id INTEGER NOT NULL,
			parent_id INTEGER NULL,
			PRIMARY KEY (id)
			) $charset_collate;";

		dbDelta($sql);
	}

	public function dropOlxAttributesTable()
	{
		$table_name = $this->olxAttributesTable;
		$sql = "DROP TABLE IF EXISTS $table_name";
		$this->db->query($sql);
	}

	public function createOlxOptionsTable()
	{
		$charset_collate = $this->db->get_charset_collate();
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$table_name = $this->olxOptionsTable;
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id INTEGER NOT NULL AUTO_INCREMENT,
			value VARCHAR (191) NOT NULL,
			olx_id INTEGER NULL,
			attribute_id INTEGER NOT NULL,
			PRIMARY KEY (id)
			) $charset_collate;";

		dbDelta($sql);
	}

	public function dropOlxOptionsTable()
	{
		$table_name = $this->olxOptionsTable;
		$sql = "DROP TABLE IF EXISTS $table_name";
		$this->db->query($sql);
	}

	public function createWcOlxAttributeTable()
	{
		$charset_collate = $this->db->get_charset_collate();
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$table_name = $this->wcOlxAttributeTable;
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id INTEGER NOT NULL AUTO_INCREMENT,
			wc_attribute_id INTEGER NOT NULL,
			olx_attribute_id INTEGER NOT NULL,
			PRIMARY KEY (id)
			) $charset_collate;";

		dbDelta($sql);
	}

	public function dropWcOlxAttributeTable()
	{
		$table_name = $this->wcOlxAttributeTable;
		$sql = "DROP TABLE IF EXISTS $table_name";
		$this->db->query($sql);
	}

	public function createWcOlxOptionTable()
	{
		$charset_collate = $this->db->get_charset_collate();
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$table_name = $this->wcOlxOptionTable;
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id INTEGER NOT NULL AUTO_INCREMENT,
			wc_option_id INTEGER NOT NULL,
			olx_option_id INTEGER NOT NULL,
			PRIMARY KEY (id)
			) $charset_collate;";

		dbDelta($sql);
	}

	public function dropWcOlxOptionTable()
	{
		$table_name = $this->wcOlxOptionTable;
		$sql = "DROP TABLE IF EXISTS $table_name";
		$this->db->query($sql);
	}

	public function createOlxCityTable()
	{
		$charset_collate = $this->db->get_charset_collate();
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$table_name = $this->olxCityTable;
		$sql = "CREATE TABLE IF NOT EXISTS $table_name (
			id INTEGER NOT NULL AUTO_INCREMENT,
			olx_id INTEGER NOT NULL,
			name VARCHAR (191) NOT NULL,
			PRIMARY KEY (id)
			) $charset_collate;";

		dbDelta($sql);
	}

	public function dropOlxCityTable()
	{
		$table_name = $this->olxCityTable;
		$sql = "DROP TABLE IF EXISTS $table_name";
		$this->db->query($sql);
	}

	/****** Create tables section end ******/


	public function getCategoryRequiredAttributes()
	{
		$cat_table = $this->olxCategoriesTable;
		$att_table = $this->olxAttributesTable;
		$sql = "SELECT categories.name as cat_name, attributes.name 
			    FROM $cat_table as categories 
			    left join $att_table as attributes on attributes.category_id = categories.id 
			    WHERE attributes.required = 1";
		return $this->db->get_results($sql);
	}

	/**
	 * Check if olx credentials already created
	 * @return bool
	 */
	public function checkIfOlxCredentialsSaved()
	{
		$credentials = $this->db->get_var("SELECT COUNT(*) FROM $this->olxCredentialsTable");
		return $credentials > 0;
	}

	/**
	 * Check if olx city saved
	 * @return bool
	 */
	public function checkIfOlxCitySaved()
	{
		$credentials = $this->db->get_var("SELECT COUNT(*) FROM $this->olxCityTable");
		return $credentials > 0;
	}

	/**
	 * @param $data
	 *
	 * @return false|int
	 */
	public function insertOlxCredentials($data)
	{
		// Check if we are updating or inserting for the first time
		if ($this->checkIfOlxCredentialsSaved()) {
			$existing = $this->db->get_var("SELECT id FROM $this->olxCredentialsTable");
			return $this->db->update($this->olxCredentialsTable, $data, ['id' => $existing]);
		}

		return $this->db->insert($this->olxCredentialsTable, $data);
	}

	/**
	 * Get OLX Credentials
	 */
	public function getCredentials()
	{
		return $this->db->get_row("SELECT * FROM $this->olxCredentialsTable");
	}

	/**
	 * @param $data
	 *
	 * @return bool|int
	 */
	public function insertOlxCategories($data)
	{
		$oldID = $data['olx_id'];
		$categoryExists = $this->db->get_var("SELECT id FROM $this->olxCategoriesTable WHERE olx_id = $oldID");
		if ($categoryExists > 0) {
			return $categoryExists;
		}

		if ($this->db->insert($this->olxCategoriesTable, $data)) {
			return $this->db->insert_id;
		}

		return false;
	}

	/**
	 * @param $data
	 * @param $id
	 *
	 * @return bool|int
	 */
	public function updateCategoryMap($data, $id)
	{
		if ($this->db->update($this->olxCategoriesTable, $data, $id)) {
			return $this->db->insert_id;
		}

		return false;
	}

	/**
	 * @param $id
	 *
	 * @return array|object|void|null
	 */
	public function getCategoryWhereMapped($id)
	{
		return $this->db->get_row("SELECT id, name FROM $this->olxCategoriesTable WHERE mapped_id = $id");
	}

	/**
	 * @return array|object|null
	 */
	public function getAllCategoriesNames()
	{
		return $this->db->get_results("SELECT name FROM $this->olxCategoriesTable where parent_id IS NULL ");
	}

	/**
	 * @param $id
	 *
	 * @return array|object|void|null
	 */
	public function getCategoryOlxIdWhereMapped($id)
	{
		return $this->db->get_row("SELECT olx_id FROM $this->olxCategoriesTable WHERE mapped_id = $id");
	}

	/**
	 * @param $id
	 *
	 * @return string|null
	 */
	public function getOlxAttributeId($id)
	{
		return $this->db->get_var("SELECT olx_attribute_id FROM $this->wcOlxAttributeTable WHERE wc_attribute_id = $id");
	}

	/**
	 * @param $id
	 *
	 * @return array|object|void|null
	 */
	public function getAttributeAll($id)
	{
		return $this->db->get_row("SELECT * FROM $this->olxAttributesTable where id = $id");
	}

	/**
	 * @param $term
	 *
	 * @return array|object|null
	 */
	public function getCategoryWhereLastAndName($term)
	{
		return $this->db->get_results("SELECT id, name FROM $this->olxCategoriesTable WHERE (last = 1 AND name LIKE '%$term%')");
	}

	/**
	 * @param $id
	 *
	 * @return array|object|void|null
	 */
	public function getMappedOlxAttribute($id)
	{
		return $this->db->get_row("SELECT id, name, type FROM $this->olxAttributesTable WHERE id = (select olx_attribute_id from $this->wcOlxAttributeTable where wc_attribute_id = $id)");
	}

	/**
	 * @param $id
	 *
	 * @return array|object|null
	 */
	public function getOptionsWhereAttribute($id)
	{
		return $this->db->get_results("SELECT * FROM $this->olxOptionsTable WHERE attribute_id = $id");
	}

	/**
	 * @param $id
	 *
	 * @return array|object|void|null
	 */
	public function getMappedOptionWhere($id)
	{
		return $this->db->get_row("SELECT olx_option_id FROM $this->wcOlxOptionTable WHERE wc_option_id = $id");
	}

	/**
	 * @param $id
	 *
	 * @return string|null
	 */
	public function getMappedOptionId($id)
	{
		return $this->db->get_var("SELECT olx_option_id FROM $this->wcOlxOptionTable where wc_option_id = $id");
	}

	/**
	 * @param $id
	 *
	 * @return array|object|void|null
	 */
	public function getOptionWhereId($id)
	{
		return $this->db->get_row("SELECT * FROM $this->olxOptionsTable where id = $id");
	}

	/**
	 * @param $id
	 *
	 * @return array|object|void|null
	 */
	public function getMappedAttributeWhere($id)
	{
		return $this->db->get_row("SELECT olx_attribute_id FROM $this->wcOlxAttributeTable WHERE (wc_attribute_id = $id)");
	}



	/**
	 * @param $term
	 *
	 * @return mixed
	 */
	public function getAttributesWithCategories($term)
	{
		return $this->db->get_results("SELECT attributes.id, attributes.name, attributes.category_id, categories.name as cat_name 
                                   FROM $this->olxAttributesTable as attributes 
                                   left join $this->olxCategoriesTable as categories on attributes.category_id = categories.id 
                                   WHERE attributes.name LIKE '%$term%';");
	}

	/**
	 * @param $wc_id
	 * @param $olx_id
	 *
	 * @return bool|false|int
	 */
	public function insertMappedAttribute($wc_id, $olx_id)
	{
		return $this->db->insert($this->wcOlxAttributeTable, ['wc_attribute_id' => $wc_id, 'olx_attribute_id' => $olx_id]);
	}

	/**
	 * @param $wc_id
	 * @param $olx_id
	 *
	 * @return bool|int
	 */
	public function deleteMappedAttribute($wc_id, $olx_id)
	{
		return $this->db->query("DELETE FROM $this->wcOlxAttributeTable WHERE (wc_attribute_id = $wc_id AND olx_attribute_id = $olx_id)");
	}

	/**
	 * @param $id
	 *
	 * @return mixed
	 */
	public function getAllOptionsWhereAttribute($id)
	{
		return $this->db->get_results("SELECT * FROM  $this->olxOptionsTable WHERE attribute_id = $id");
	}

	/**
	 * @param $wc_id
	 * @param $olx_id
	 *
	 * @return bool|false|int
	 */
	public function insertMappedOption($wc_id, $olx_id)
	{
		return $this->db->insert($this->wcOlxOptionTable, ['wc_option_id' => $wc_id, 'olx_option_id' => $olx_id]);
	}

	/**
	 * @param $wc_id
	 * @param $olx_id
	 *
	 * @return bool|int
	 */
	public function deleteMappedOption($wc_id, $olx_id)
	{
		return $this->db->query("DELETE FROM $this->wcOlxOptionTable WHERE (wc_option_id = $wc_id AND olx_option_id = $olx_id)");
	}

	/**
	 * Find OLX Attribute by Name
	 * @param $name
	 *
	 * @return string|null
	 */
	public function findOlxAttributeByName($name)
	{
		return $this->db->get_var("SELECT COUNT(*) FROM $this->olxAttributesTable where field = '$name'");
	}

	/**
	 * Find OLX Brand by ID
	 * @param $name
	 *
	 * @return string|null
	 */
	public function findOlxBrandByNameAndCategory($name, $category_id)
	{
		return $this->db->get_var("SELECT COUNT(*) FROM $this->olxAttributesTable where (name = '$name' AND category_id = $category_id)");
	}

	public function findOlxCarModelByName($name)
	{
		$attributeExists = $this->db->get_var("SELECT id FROM $this->olxAttributesTable WHERE name = '$name'");
		if ($attributeExists > 0) {
			return $attributeExists;
		}

		return false;
	}

	/**
	 * Insert OLX Attribute
	 *
	 * @param $data
	 *
	 * @return bool|int
	 */
	public function insertOlxAttribute($data)
	{
		try {
			$this->db->insert($this->olxAttributesTable, $data);
			return $this->db->insert_id;
		} catch (Exception $exception) {
			return false;
		}
	}

	/**
	 * Check if OLX Option exists
	 *
	 * @param $id
	 * @param $option
	 *
	 * @return string|null
	 */
	public function checkIfOlxOptionExists($id, $option)
	{
		return $this->db->get_var("SELECT COUNT(*) FROM $this->olxOptionsTable where (attribute_id = $id AND value = '$option')");
	}

	/**
	 * Insert OLX Attribute option
	 *
	 * @param $data
	 *
	 * @return bool|int
	 */
	public function insertOLXOption($data)
	{
		try {
			$this->db->insert($this->olxOptionsTable, $data);
			return $this->db->insert_id;
		} catch (Exception $exception) {
			return false;
		}
	}

	/**
	 * @return array|object|null
	 */
	public function getAllCitiesNames()
	{
		return $this->db->get_results("SELECT name FROM $this->olxCityTable");
	}

	/**
	 * Insert OLX City
	 *
	 * @param $data
	 *
	 * @return bool|int|string|null
	 */
	public function insertOLXCity($data)
	{
		$cityExists = $this->db->get_var("SELECT id FROM $this->olxCityTable");
		if ($cityExists > 0) {
			$this->db->query("DELETE FROM $this->olxCityTable WHERE id = $cityExists");
		}

		if ($this->db->insert($this->olxCityTable, $data)) {
			return $this->db->insert_id;
		}

		return false;
	}
}
