<?php

class
AggOlxCategory
{
	protected $db, $requester;

	/**
	 * AggOlxCategory constructor.
	 *
	 * @param AggDatabase $db
	 * @param AggRequester $requester
	 */
	public function __construct(AggDatabase $db, AggRequester $requester)
	{
		$this->db = $db;
		$this->requester = $requester;
		add_action( 'wp_ajax_agg_get_selected_category_sub_categories', array($this, 'agg_get_selected_category_sub_categories_ajax_callback') );
		add_action( 'wp_ajax_agg_save_user_selected_category', array($this, 'agg_olx_agg_save_user_selected_category_ajax_callback') );
		add_action('edited_product_cat', array($this, 'agg_save_update_olx_category_map'), 10, 1);
		add_action('product_cat_add_form_fields', array($this, 'agg_add_olx_category_map_field'), 10, 1);
		add_action('product_cat_edit_form_fields', array($this, 'agg_edit_olx_category_map_field'), 10, 1);
		add_action('wp_ajax_agg_olx_category_map', array($this, 'agg_olx_categories_map_ajax_callback'));
		add_action('create_product_cat', array($this, 'agg_save_add_olx_category_map'), 10, 1);
		add_action('woocommerce_after_edit_attribute_fields', array($this, 'agg_edit_olx_attribute_map_field'), 10, 1);
		add_action('woocommerce_attribute_updated', array($this, 'agg_updated_olx_attribute_map_field'), 10, 1);
		add_action( 'wp_ajax_agg_olx_attribute_map', array($this, 'agg_olx_attributes_map_ajax_callback') );
		add_action( 'wp_ajax_agg_get_selected_attribute_options', array($this, 'agg_get_selected_attribute_options_ajax_callback') );
	}

	/**
	 * Get category subcategories
	 */
	public function agg_get_selected_category_sub_categories_ajax_callback(){

		$categoryID = $_REQUEST['category_id'];

		try {
			$categories = $this->getCategory($categoryID);
			wp_send_json_success(['message' => 'Categories saved', 'data' => $categories]);
		} catch (Exception $exception) {
			wp_send_json_error(['message' => 'Error fetching categories']);
			die();
		}
	}

	/**
	 * Save selected category
	 */
	public function agg_olx_agg_save_user_selected_category_ajax_callback(){

		$category_id = $_REQUEST['category_id'];
		$main_category_id = $_REQUEST['main_category_id'];

		try {
			$this->fetchCategories($main_category_id, $category_id);
			wp_send_json_success(['message' => 'Categories saved']);
		} catch (Exception $exception) {
			wp_send_json_error(['message' => 'Error fetching categories']);
			die();
		}
	}

	/**
	 * Save mapping for WP category with OLX category on edit
	 *
	 * @param $category_id
	 */
	public function agg_save_update_olx_category_map($category_id) {

		$agg_olx_category_map = filter_input(INPUT_POST, 'agg_olx_category_map');

		if (is_null($category_id) || is_null($agg_olx_category_map)) {
			return;
		}

		$data = ['mapped_id' => $category_id];
		$id = ['id' => $agg_olx_category_map];

		$this->db->updateCategoryMap($data, $id);
	}

	/**
	 * Fetch categories from OLX
	 *
	 * @param $main
	 * @param $id
	 */
	public function fetchCategories($main, $id)
	{
		$url = "https://www.olx.ba/api/kategorije";
		$result = $this->requester->get($url);

		if ($result) {
			$this->insertCategories($result['kategorije'], $main, $id);
		}
	}

	/**
	 * @param $categories
	 * @param $id
	 */
	private function insertCategories($categories, $main, $id)
	{
		foreach ($categories as $category) {
			if ($category['id'] == $main) {
				$this->loopCategories($category, $id, null);
			}
		}
	}

	/**
	 * @param $id
	 *
	 * @return mixed|null
	 */
	public function getCategory($id)
    {
	    $url = "https://www.olx.ba/api/kategorije";
	    $result = $this->requester->get($url);

	    if ($result) {
		    foreach ($result['kategorije'] as $category) {
			    if ($category['id'] == $id) {
			        return $category;
			    }
		    }
	    }

	    return null;
    }

	/**
	 * Recursively loop and store all categories, attributes, and options
	 *
	 * @param $category
	 * @param null $parentID
	 */
	private function loopCategories($category, $id, $parentID = null)
	{
	    if ($category['id'] === $id) {
		    $data = [
			    'name'      => $category['naziv'],
			    'olx_id'    => $category['id'],
			    'parent_id' => $parentID ? $parentID : null
		    ];

		    // Created or existing category id
		    $created = $this->db->insertOlxCategories($data);

		    // Fetch attributes associated with the category
		    $id = $category['id'];

		    // Get all category attributes and options
		    $cat_url = "https://www.olx.ba/api/kategorije/$id";
		    $cat_result = $this->requester->get($cat_url);

		    // Set subcategory as last
		    $this->db->updateCategoryMap(['last' => 1], ['id' => $created]);

		    if ($cat_result) {
			    if (isset($cat_result['polja'])) {
				    foreach ($cat_result['polja'] as $field) {
					    $name = $field['name'];

					    // Check if attribute already saved
					    $olx_attribute = $this->db->findOlxAttributeByName($name);
					    if ($olx_attribute == 0) {
						    $data = [
							    'name'        => $field['naziv'],
							    'field'       => $name,
							    'type'        => $field['tip'],
							    'category_id' => $created,
                                'required'    => $field['obavezno']
						    ];
						    try {
							    // Create new attribute
							    $saved_attribute = $this->db->insertOlxAttribute($data);
							    if ($saved_attribute) {
								    // If attribute type is select save all available options
								    if ($field['tip'] === 'select') {
									    // Create attribute options
									    foreach ($field['opcije'] as $option) {
										    // Check if attribute option already saved
										    if (!empty($option)) {
											    // Create new attribute option
											    $olxOption = $this->db->checkIfOlxOptionExists($saved_attribute, $option);
											    if ($olxOption == 0) {
												    $data = [
													    'attribute_id' => $saved_attribute,
													    'value'        => $option
												    ];
												    $this->db->insertOLXOption($data);
											    }
										    }
									    }
								    } elseif ($field['tip'] === 'checkbox') {
                                        $olxOptionYes = $this->db->checkIfOlxOptionExists($saved_attribute,'da');
                                        if ($olxOptionYes == 0) {
                                            $data = [
                                                'attribute_id' => $saved_attribute,
                                                'value'        => 'da'
                                            ];
                                            $this->db->insertOLXOption($data);
                                        }
                                        $olxOptionYes = $this->db->checkIfOlxOptionExists($saved_attribute,'ne');
                                        if ($olxOptionYes == 0) {
                                            $data = [
                                                'attribute_id' => $saved_attribute,
                                                'value'        => 'ne'
                                            ];
                                            $this->db->insertOLXOption($data);
                                        }
                                    } else {
									    // There are no options / regular text value is sent
								    }
							    }
						    } catch (Exception $exception) {
						    }
					    }
				    }
			    }
		    }

		    // Fetch brands associated with the category
		    $brand_url = "https://www.olx.ba/api/brendovi/$id";
		    $brand_result = $this->requester->get($brand_url);

		    if ($brand_result) {
			    if (isset($brand_result['brendovi'])) {
				    $data = [
					    'name'        => 'Brands',
					    'field'       => null,
					    'type'        => 'brand',
					    'category_id' => $created,
					    'required'    => $field['obavezno']
				    ];

				    // Check if brand already saved
				    $olx_brand = $this->db->findOlxBrandByNameAndCategory('Brands', $created);
				    if ($olx_brand == 0) {
					    // Create attribute
					    $saved_attribute = $this->db->insertOlxAttribute($data);
					    // Add brands as options to brand attribute
					    foreach ( $brand_result['brendovi'] as $brand ) {
						    $name = $brand['naziv'];
						    $olx_option = $this->db->checkIfOlxOptionExists($saved_attribute, $name);
						    if ($olx_option == 0) {
							    $data = [
								    'attribute_id' => $saved_attribute,
								    'value'        => $name,
								    'olx_id'       => $brand['id']
							    ];
							    $this->db->insertOLXOption($data);
						    }
					    }
				    }
			    }
		    }

		    if ($category['id'] == 18) {
			    $car_url = "https://www.olx.ba/api/vozila_brendovi";
			    $car_result = $this->requester->get($car_url);

			    if ($car_result) {
				    if (isset($car_result['brendovi'])) {
					    $data = [
						    'name'        => 'Car Brands',
						    'field'       => null,
						    'type'        => 'car-brand',
						    'category_id' => $created,
						    'required'    => $field['obavezno']
					    ];
					    // Check if car brand already saved
					    $olx_car_brand = $this->db->findOlxBrandByNameAndCategory('Car Brands', $created);
					    if ($olx_car_brand == 0) {
						    $saved_car_attribute = $this->db->insertOlxAttribute($data);
						    foreach ( $car_result['brendovi'] as $brand ) {
							    $name = $brand['naziv'];
							    $olx_option = $this->db->checkIfOlxOptionExists($saved_car_attribute, $name);
							    if ($olx_option == 0) {
								    $data = [
									    'attribute_id' => $saved_car_attribute,
									    'value'        => $name,
									    'olx_id'       => $brand['id']
								    ];
								    $saved_car_option = $this->db->insertOLXOption($data);

								    // Save models for each car brand
								    $brand_id = $brand['id'];
								    $car_model_url = "https://www.olx.ba/api/vozila_modeli/$brand_id";
								    $car_model_result = $this->requester->get($car_model_url);

								    if ($car_model_result) {
									    if ( isset( $car_model_result['modeli'] ) ) {
										    $data = [
											    'name'        => 'Car Models',
											    'field'       => null,
											    'type'        => 'car-model',
											    'category_id' => $created,
											    'parent_id'   => $saved_car_option,
											    'required'    => $field['obavezno']
										    ];

										    // Check if car model already saved
										    $olx_car_model = $this->db->findOlxCarModelByName('Car Models');
										    if (!$olx_car_model) {
											    $olx_car_model = $this->db->insertOlxAttribute($data);
										    }

										    foreach ( $car_model_result['modeli'] as $model ) {
											    $name = $model['naziv'];
											    $olx_model_option = $this->db->checkIfOlxOptionExists($olx_car_model, $name);
											    if ($olx_model_option == 0) {
												    $data = [
													    'attribute_id' => $olx_car_model,
													    'value'        => $name,
													    'olx_id'       => $model['id']
												    ];
												    $this->db->insertOLXOption($data);
											    }
										    }
									    }
								    }
							    }
						    }
					    }
				    }
			    }
		    }

	    } else {
		    // Check if category has sub categories
            if (isset($category['potkategorije'])) {
                if (count($category['potkategorije'])) {
                    foreach ($category['potkategorije'] as $sub) {
                        $this->loopCategories($sub, $id, null);
                    }
                }
            }
        }
	}

	/**
	 *  Add olx category on add new category wp screen
	 */
	public function agg_add_olx_category_map_field() {
		?>
        <div class="form-field">
            <label for="olx-category-map-select">OLX Category</label>
            <select class="olx-category-map-select" id="olx-category-map-select" name="agg_olx_category_map" style="width: 100%">
            </select>
            <p class="description"><?php _e('Map this category to OLX store category', 'wh'); ?></p>
        </div>
		<?php
	}

	/**
	 * Add olx category on edit category wp screen
	 *
	 * @param $term
	 */
	public function agg_edit_olx_category_map_field($term) {

		$agg_olx_category_map = $this->db->getCategoryWhereMapped($term->term_id);
		?>
        <tr class="form-field">
            <th scope="row"><label for="agg_olx_category_map"><?php _e('OLX category', 'wh'); ?></label></th>
            <td>
                <select class="olx-category-map-select" name="agg_olx_category_map" style="width: 100%">
					<?php
					if ($agg_olx_category_map)
						echo "<option value='$agg_olx_category_map->id'>$agg_olx_category_map->name</option>"
					?>
                </select>
                <p class="description"><?php _e('Map category to OLX store category', 'wh'); ?></p>
            </td>
        </tr>
		<?php
	}

	/**
	 * Ajax request for categories
	 */
	public function agg_olx_categories_map_ajax_callback() {

		$term = $_GET['search'];
		$olx_categories = $this->db->getCategoryWhereLastAndName($term);
		echo json_encode( $olx_categories );
		die;
	}

	/**
	 * Save mapping for WP category with OLX category on add
	 *
	 * @param $category_id
	 */
	public function agg_save_add_olx_category_map($category_id) {

		$agg_olx_category_map = filter_input(INPUT_POST, 'agg_olx_category_map');

		if (is_null($category_id) || is_null($agg_olx_category_map)) {
			return;
		}

		$data = ['mapped_id' => $category_id];
		$id = ['id' => $agg_olx_category_map];

		$this->db->updateCategoryMap($data, $id);
	}

	/**
	 *  Add olx attribute on edit wp attribute
	 */
	public function agg_edit_olx_attribute_map_field() {

		$attribute = wc_get_attribute($_GET['edit']);

		$agg_olx_attribute_map = $this->db->getMappedOlxAttribute($attribute->id);

		$terms = get_terms( array(
			'taxonomy' => $attribute->slug,
			'hide_empty' => false,
		));

		$options = $this->db->getOptionsWhereAttribute($agg_olx_attribute_map->id);
		$html = "";
		if (!is_null($agg_olx_attribute_map)) {
			$html .= "<table id='olx-appended-options'> 
                     <tr>
                        <th>WC Option</th>
                        <th>OLX Option</th> 
                     </tr>
                ";

			foreach ($terms as $term) {
				$wcID = $this->db->getMappedOptionWhere($term->term_id);

				$html.= "<tr>
                        <td>$term->name</td>
                        <td>
                            <select name='term-id-$term->term_id'>
                            ".
                            $this->createOlxAttributeOptions($options, isset($wcID->olx_option_id) ? $wcID->olx_option_id : false)
                            ."
                            </select>
                        </td>
                    </tr>";
			}
			$html.= '</table>';
		}

		?>
        <tr class="form-field form-required">
            <th scope="row" valign="top">
                <label for="olx-attribute-select"><?php esc_html_e( 'OLX Attribute', 'woocommerce' ); ?></label>
            </th>
            <td>
                <select id="olx-attribute-select" data-attr-id="<?php echo $attribute->id ?>" class="olx-attribute-map-select" name="olx-attribute-map-select" style="width: 100%">
					<?php
					if ($agg_olx_attribute_map)
						echo "<option value='$agg_olx_attribute_map->id'>$agg_olx_attribute_map->name</option>"
					?>
                </select>
                <p class="description"><?php esc_html_e( 'OLX product attribute', 'woocommerce' ); ?></p>
            </td>
        </tr>
        <tr class="form-field">
            <th scope="row" valign="top">
                <label for="olx-attribute-option-select"><?php esc_html_e( 'Attribute Options', 'woocommerce' ); ?></label>
            </th>
            <td id="olx-attribute-options-map">
				<?php
            if (sizeof($options) > 0) {
                if (!is_null($agg_olx_attribute_map)) {
					echo $html;
                }
            } else {
                echo 'Ovo je tekstualni atribut i nije potrebno da se mapira';
            }
				?>
            </td>
        </tr>
		<?php
	}

	/**
	 * Saved mapped olx attribute and wp attribute
	 *
	 * @param $attribute
	 */
	public function agg_updated_olx_attribute_map_field($attribute)
	{
	    if (isset($_POST['olx-attribute-map-select'])) {
            $olx_map_attribute = $_POST['olx-attribute-map-select'];

            if (!is_null($olx_map_attribute)) {

                $attributeExists = $this->db->getMappedAttributeWhere($attribute);
                if ($attributeExists) {
                    if ($attributeExists->olx_attribute_id === $olx_map_attribute) {
                    } else {
                        $this->db->deleteMappedAttribute($attribute, $attributeExists->olx_attribute_id);
                        $this->db->insertMappedAttribute($attribute, $olx_map_attribute);
                    }
                } else {
                    $this->db->insertMappedAttribute($attribute, $olx_map_attribute);
                }

                $options = $this->preg_grep_keys('/term-id-([\d]+)/', $_POST);

                for ($i = 0; $i < sizeof($options[0]); $i++)  {

                    $wcID  = $options[0][$i];
                    $olxID = $options[1][$i];

                    $optionExists = $this->db->getMappedOptionWhere($wcID);

                    if ($optionExists) {
                        if ($optionExists->olx_option_id === $olxID) {
                        } else {
                            $this->db->deleteMappedOption($wcID, $optionExists->olx_option_id);
                            $this->db->insertMappedOption($wcID, $olxID);
                        }
                    } else {
                        $this->db->insertMappedOption($wcID, $olxID);
                    }
                }
            }
        }

    }

	/**
	 * Get attribute ids from form
	 *
	 * @param $pattern
	 * @param $input
	 * @param int $flags
	 *
	 * @return array[]
	 */
	public function preg_grep_keys( $pattern, $input, $flags = 0 )
	{
		$keys = preg_grep( $pattern, array_keys( $input ), $flags );
		$wc_options = array();
		$olx_options = array();
		foreach ( $keys as $key )
		{
			preg_match($pattern, $key, $matched);
			array_push($wc_options, $matched[1]);
			array_push($olx_options, $input[$key]);
		}
		return [$wc_options, $olx_options];
	}

	public function agg_olx_attributes_map_ajax_callback(){

		$term = $_GET['search'];
		$olx_attributes = $this->db->getAttributesWithCategories($term);
		echo json_encode( $olx_attributes );
		die;
	}

	public function agg_get_selected_attribute_options_ajax_callback(){

		$attributeID = $_REQUEST['attribute_id'];
		$olxAttributeID = $_REQUEST['olx_attribute_id'];

		$attribute = wc_get_attribute($attributeID);

		$terms = get_terms( array(
			'taxonomy' => $attribute->slug,
			'hide_empty' => false,
		));

		$options = $this->db->getAllOptionsWhereAttribute($olxAttributeID);

		if (sizeof($options) > 0) {
            $html = "<table id='olx-appended-options'> 
                     <tr>
                        <th>WC Option</th>
                        <th>OLX Option</th> 
                     </tr>
                ";


            foreach ($terms as $term) {
                $html.= "<tr>
                        <td>$term->name</td>
                        <td>
                            <select name='term-id-$term->term_id'>
                            ".
                            $this->createOlxAttributeOptions($options)
                            ."
                            </select>
                        </td>
                    </tr>";
            }
            $html.= '</table>';

        } else {
		    $html = 'Ovo je tekstualni atribut i nije potrebno da se mapira';
        }

		echo json_encode($html);
		die;
	}

	public function createOlxAttributeOptions($options, $selected = null)
	{
		$html = '';
		foreach ($options as $option) {
			$html.= "<option ".($selected == $option->id ? 'selected' : '') ." value='$option->id'>$option->value</option>";
		}

		return $html;
	}
}