<?php

class AggProduct
{
	protected $requester, $db;

	public function __construct(AggDatabase $db, AggRequester $requester)
	{
		$this->db = $db;
		$this->requester = $requester;
		add_action('admin_head', array($this, 'olx_product_css_icon'));
		add_action( 'woocommerce_update_product', array($this, 'agg_wc_product_updated'), 10, 1 );
		add_filter('woocommerce_product_data_tabs', array($this, 'agg_product_settings_tabs') );
		add_action( 'woocommerce_product_data_panels', array($this, 'agg_product_panel_option_group') );
		add_action( 'woocommerce_process_product_meta', array($this, 'agg_add_custom_general_fields_save') );
        add_action( 'admin_notices', array($this, 'olxPushError') );
    }

	public function agg_wc_product_updated( $product_id ) {
        add_filter( 'show_olx_error', array( $this, 'add_notice_query_var' ), 99 );

		// Stop if credentials not saved
		if (!$this->db->checkIfOlxCredentialsSaved()) return;

		// Stop if city not saved
		if (!$this->db->checkIfOlxCitySaved()) return;

		$product = wc_get_product( $product_id );

		$productCategories = $product->get_category_ids();
		if (sizeof($productCategories) > 0) {

			$olxCategory = null;
			foreach ( $productCategories as $product_category ) {
				$result = $this->db->getCategoryOlxIdWhereMapped($product_category);

				if (is_null($result)) {
					continue;
				}

				$olxCategory = $result;
			}

			// If category not mapped abort upload
			if (is_null($olxCategory)) {
//                add_filter( 'show_olx_error', array( $this, 'add_notice_query_var' ), 99 );
                $_SESSION['OLX_PUSH_ERROR'] = 'Kategorija nije povezana sa OLX kategorijom';
                return;
			}

			// Attributes with options
			$fields = [];

			// Brand
			$brand = null;
			$car_model_id = null;

			$productAttributes = $product->get_attributes();
			foreach ( $productAttributes as $product_attribute ) {
				$wcID = $product_attribute->get_id();
				$olxAttributeID = $this->db->getOlxAttributeId($wcID);

				if ($olxAttributeID == 0) {
					continue;
				}

				$olxAttribute = $this->db->getAttributeAll($olxAttributeID);
				if ($olxAttributeID == 0) {
					continue;
				}

				if ($olxAttribute->type === 'text') {
					$options = $product_attribute->get_options();
					if (sizeof($options) > 0) {
						$option = get_term($options[0]);

						preg_match('/polje([\d]+)/', $olxAttribute->field, $matched);
						if (isset($matched[1])) {
							$sendAttrID = $matched[1];
							$value = $option->name;
							array_push($fields, ['id' => $sendAttrID, 'vrijednost' => $value]);
						} else {
							continue;
						}
					} else {
						continue;
					}
				}  else {
					$wcOptions = $product_attribute->get_options();
					$olxOptions = [];

					foreach ( $wcOptions as $optionID ) {
						$olxOptionPivot = $this->db->getMappedOptionId($optionID);
						if ($olxOptionPivot == 0) {
							continue;
						}

						$olxOption = $this->db->getOptionWhereId($olxOptionPivot);
						if (is_null($olxOption)) {
							continue;
						}

						// If type is brand we take id and not field
						if ($olxAttribute->type === 'brand') {
							$brand = $olxOption->olx_id;
						} elseif ($olxAttribute->type === 'car-model') {
							$car_model_id = $olxOption->olx_id;
						} else {
							preg_match('/polje([\d]+)/', $olxAttribute->field, $matched);
							if (isset($matched[1])) {
								$sendAttrID = $matched[1];
								$value = $olxOption->value;
								if ($value === 'ne') {
								    $value = '';
                                }
								array_push($fields, ['id' => $sendAttrID, 'vrijednost' => $value ]);
							} else {
								continue;
							}
						}

					}
				}
			}

			$data = [
				'naslov'        => substr($product->get_name(), 0, 54),
				'kategorija_id' => $olxCategory->olx_id,
				'grad_id'       => 3812,
				'cijena'        => $product->get_price(),  // Cijena 0 predstavlja po dogovoru
				'interna_sifra' => $product->get_sku(),
				'kratki_opis'   => $product->get_short_description(),
				'opis'          => $product->get_description(),
				'kolicina'      => $product->get_stock_quantity(),
				'polja'         => $fields,
			];

			$availability = get_post_meta($product->get_id(), 'olx_availability', true);
			if (!is_null($availability)) {
				$data['dostupnost'] = $availability;
			}

			$condition = get_post_meta($product->get_id(), 'olx_condition', true);
			if (!is_null($condition)) {
				$data['novo'] = $condition;
			}

			$replacement = get_post_meta($product->get_id(), 'olx_replacement', true);
			if (!is_null($replacement)) {
				$data['zamjena'] = $replacement;
			}

			$free_shipping = get_post_meta($product->get_id(), 'olx_free_shipping', true);
			if (!is_null($free_shipping)) {
				$data['besplatna_dostava'] = $free_shipping;
			}

			$sale_terms = get_post_meta($product->get_id(), 'olx_sale_terms', true);
			if (!is_null($sale_terms)) {
				$data['uslovi_prodaje'] = $sale_terms;
			}

			// Add main image
			$product_image = wp_get_attachment_image_src($product->get_image_id(), 'full')[0];
			if ($product_image) {
			$data['slika_url'] = $product_image;
            //$_SESSION['OLX_PUSH_ERROR'] = $data['slika_url'];
			}

			if (!is_null($brand)) {
				$data['brend_id'] = $brand;
			}

			if (!is_null($car_model_id)) {
				$data['vozilo_model'] = $car_model_id;
			}

			// Add gallery
			$gallery = [];
			$product_gallery_ids = $product->get_gallery_image_ids();
			if (sizeof($product_gallery_ids)) {
				foreach ( $product_gallery_ids as $id ) {
					array_push($gallery, wp_get_attachment_image_src($id, 'full')[0]);
					$_SESSION['OLX_PUSH_ERROR'] = wp_get_attachment_image_src($id, 'full')[0];
				}
				$data['slike'] = $gallery;
				
			}

			$url = 'https://www.olx.ba/api/artikli/snimi';

			$olx_product_id = get_post_meta($product->get_id(), 'olx_id', true);
			if ($olx_product_id) {
				$url = "https://www.olx.ba/api/artikli/$olx_product_id/izmjeni";
			}

			$sendArticle = $this->requester->post($url, $data);
//            throw new Exception(json_encode($sendArticle));
			if ($sendArticle['success'] == true) {
				if ($sendArticle['artikal']['id'] !== $olx_product_id) {
					$product->update_meta_data('olx_id', $sendArticle['artikal']['id']);
					$product->save();
				}
			} else {
			    if (isset($sendArticle['errors'])) {
			        $fields = "Obavezna polja:";
                    $keys = array_keys($sendArticle['errors']);
                    foreach ($keys as $key) {
                        foreach ($sendArticle['errors'][$key] as $error) {
                            $fields .= '&nbsp;'.$key. '&nbsp;obavezno';
                        }
                    }
			        foreach ($sendArticle['errors']['obavezna_polja'] as $error) {
                        $fields .= '&nbsp;'.$error['naziv'];
                    }
                    $_SESSION['OLX_PUSH_ERROR'] = $fields;
                } else {
                    $_SESSION['OLX_PUSH_ERROR'] = 'Doslo je do greske';
                }

            }
		}
	}

    function olxPushError() {
        if (!isset($_SESSION['OLX_PUSH_ERROR'])) {
            return;
        }
        ?>
        <div class="error notice">
            <p><?php _e( $_SESSION['OLX_PUSH_ERROR']); ?></p>
        </div>
        <?php
        unset($_SESSION['OLX_PUSH_ERROR']);
    }

	/**
	 * Add Olx shop icon
	 */
	public function olx_product_css_icon(){
		echo '<style>
				#woocommerce-product-data ul.wc-tabs li.olx_options.olx_tab a:before{
					content: "\f513";
				}
			 </style>';
	}

	/**
	 * @param $tabs
	 *
	 * @return mixed
	 */
	public function agg_product_settings_tabs( $tabs ){

		$tabs['olx'] = array(
			'label'    => 'OLX Shop',
			'target'   => 'olx_product_data',
			'priority' => 21,
		);
		return $tabs;

	}

	/**
	 * Save custom OLX options
	 *
	 * @param $post_id
	 */
	public function agg_add_custom_general_fields_save( $post_id ){

		$olx_condition = isset( $_POST['olx_condition'] ) ? 1 : 0;
		update_post_meta( $post_id, 'olx_condition', $olx_condition );

		$olx_replacement = isset( $_POST['olx_replacement'] ) ? 1 : 0;
		update_post_meta( $post_id, 'olx_replacement', $olx_replacement );

		$olx_free_shipping = isset( $_POST['olx_free_shipping'] ) ? 1 : 0;
		update_post_meta( $post_id, 'olx_free_shipping', $olx_free_shipping );

		$olx_sale_terms = isset( $_POST['olx_sale_terms'] ) ? $_POST['olx_sale_terms'] : '';
		update_post_meta( $post_id, 'olx_sale_terms', $olx_sale_terms );

		$olx_availability = isset( $_POST['olx_availability'] ) ? $_POST['olx_availability'] : '';
		update_post_meta( $post_id, 'olx_availability', $olx_availability );

	}

	/**
	 * Add custom OLX options
	 */
	public function agg_product_panel_option_group() {
		echo '<div id="olx_product_data" class="panel woocommerce_options_panel">';

		$olx_condition_old = get_post_meta( get_the_ID(), 'olx_condition', true );
		woocommerce_wp_checkbox( array(
				'id'            => 'olx_condition',
				'label'         => 'Stanje',
				'value'         => get_post_meta( get_the_ID(), 'olx_condition', true ),
				'cbvalue'       => $olx_condition_old !== null && $olx_condition_old != 0 ? $olx_condition_old : false,
				'description'   => __( 'Proizvod je nov', 'woocommerce' )
			)
		);

		$olx_replacement_old = get_post_meta( get_the_ID(), 'olx_replacement', true );
		woocommerce_wp_checkbox( array(
				'id'            => 'olx_replacement',
				'label'         => 'Zamjena',
				'value'         => get_post_meta( get_the_ID(), 'olx_replacement', true ),
				'cbvalue'       => $olx_replacement_old !== null && $olx_replacement_old != 0 ? $olx_replacement_old : false,
				'description'   => __( 'Moze zamjena', 'woocommerce' )
			)
		);

		$olx_free_shipping = get_post_meta( get_the_ID(), 'olx_free_shipping', true );
		woocommerce_wp_checkbox( array(
				'id'            => 'olx_free_shipping',
				'label'         => 'Dostava',
				'value'         => get_post_meta( get_the_ID(), 'olx_free_shipping', true ),
				'cbvalue'       => $olx_free_shipping !== null && $olx_free_shipping != 0 ? $olx_free_shipping : false,
				'description'   => __( 'Besplatna dostava', 'woocommerce' )
			)
		);

		woocommerce_wp_textarea_input( array(
			'id'          => 'olx_sale_terms',
			'value'       => get_post_meta( get_the_ID(), 'olx_sale_terms', true ),
			'label'       => 'Uslovi prodaje',
			'desc_tip'    => true,
		) );

		woocommerce_wp_select( array(
			'id'          => 'olx_availability',
			'value'       => get_post_meta( get_the_ID(), 'olx_availability', true ),
			'label'       => 'Availability',
			'options'     => array( '' => 'Please select', 'svugdje' => 'Svugdje', 'samobih' => 'Samo BiH', 'samomojgrad' => 'Samo moj grad', 'samomojkanton' => 'Samo moj kanton'),
		) );
		echo '</div>';
	}
}
