<?php

class AggRequester
{
	private $headers, $db;

	/**
	 * AggRequester constructor.
	 *
	 * @param AggDatabase $db
	 */
	public function __construct(AggDatabase $db)
	{
		$this->db = $db;
		$this->headers = $this->setHeaders();
	}

	/**
	 * Make Get Request
	 *
	 * @param $url
	 *
	 * @return array|mixed
	 */
	public function get($url)
	{
		if (!empty($this->headers)) {
			$options = [
					CURLOPT_RETURNTRANSFER => 1,
					CURLOPT_URL            => $url,
					CURLOPT_HTTPHEADER     => $this->headers
				];
			return $this->makeRequest($options);
		}
		return false;
	}

	/**
	 * Make Post Request
	 *
	 * @param $url
	 * @param $params
	 *
	 * @return array|bool|mixed
	 */
	public function post($url, $params)
	{
		if (!empty($this->headers)) {
			$options = [
				CURLOPT_RETURNTRANSFER => 1,
				CURLOPT_URL            => $url,
				CURLOPT_HTTPHEADER     => $this->headers,
				CURLOPT_POST           => true,
				CURLOPT_POSTFIELDS     => http_build_query($params)
			];
			return $this->makeRequest($options);
		}
		return false;
	}

	/**
	 * Make Curl request
	 *
	 * @param $options
	 *
	 * @return array|bool|mixed
	 */
	private function makeRequest($options)
	{
		$curl = curl_init();
		curl_setopt_array($curl, $options);

		$response = curl_exec($curl);
		if (curl_error($curl)) {
			$error = curl_error($curl);
			$code  = curl_errno($curl);
		}
		curl_close ($curl);
		$decodedResponse = json_decode($response, true);

		if (isset($error) && isset($code)) {
			return ['message' => $error, 'code' => $code];
		}

		if (isset($error)) {
			return ['message' => $error];
		}

		if ($decodedResponse) {
			return $decodedResponse;
		}

		return false;
	}

	/**
	 * Retrieve Credentials and Set CURL Headers
	 * @return array|string[]
	 */
	private function setHeaders()
	{
		$credentials = $this->db->getCredentials();
		if ($credentials) {
			return [
				"OLX-CLIENT-ID: $credentials->client_id",
				"OLX-CLIENT-TOKEN: $credentials->client_token",
				"Content-Type: application/json"
			];
		}

		return [];
	}
}