<?php

/**
 * Plugin Name: OLX Shop
 * Plugin URI: https://misija.io/
 * Description: Sync products from WooCommerce with OLX store
 * Version: 1.0
 * Author: Misija.io
 * Author URI: https://misija.io/
 **/

session_start();

// Import AggPageBuilder class
require_once 'agg-page-builder.php';

// Import AggFormRequest class
require_once 'agg-form-request.php';

// Import AggDatabase class
require_once 'agg-database.php';

// Import AggOlxCategory
require_once 'agg-olx-category.php';

// Import AggRequester
require_once 'agg-requester.php';

// Import AggProduct
require_once 'agg-product.php';

// Import AggCity
require_once 'agg-city.php';

class AggSync {
    protected $db, $pageBuilder, $cred_form, $requester, $product, $city, $category;

	/**
	 * AggSync constructor.
	 */
	public function __construct()
    {
        $this->db = new AggDatabase();
		$this->cred_form = new AggFormRequest();
		$this->requester = new AggRequester($this->db);
        $this->pageBuilder = new AggPageBuilder($this->db, $this->requester);
		$this->product = new AggProduct($this->db, $this->requester);
		$this->city = new AggCity($this->db, $this->requester);
		$this->category = new AggOlxCategory($this->db, $this->requester);
	    register_activation_hook( __FILE__, array($this, 'agg_plugin_activated' ));
		register_deactivation_hook( __FILE__, array($this, 'agg_plugin_deactivated' ));
	    add_action( 'admin_enqueue_scripts', array($this, 'loadScripts') );
    }

	/**
	 * Register all required scripts
	 */
	public function loadScripts()
    {
	    wp_register_style( 'select2css', '//cdnjs.cloudflare.com/ajax/libs/select2/4.0.12/css/select2.min.css', false, '1.0', 'all' );
	    wp_register_script( 'select2', '//cdnjs.cloudflare.com/ajax/libs/select2/4.0.12/js/select2.min.js', array( 'jquery' ), '1.0', true );
	    wp_enqueue_style( 'select2css' );
	    wp_enqueue_script( 'select2' );

	    wp_register_script( 'agg_admin_script', plugins_url('/assets/js/app.js',__FILE__ ));
	    wp_enqueue_script('agg_admin_script');
    }

	/**
	 * Register activation hook
	 */
	public function agg_plugin_activated()
    {
	    $this->db->createAllTables();
    }

	/**
	 * Register deactivation hook
	 */
	public function agg_plugin_deactivated()
    {
        // We delete tables only on plugin uninstall
    }
}

// App instance
$app = new AggSync();