<?php
/**
 * My Addresses
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/my-address.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 2.6.0
 */

defined( 'ABSPATH' ) || exit;

$customer_id = get_current_user_id();

if ( ! wc_ship_to_billing_address_only() && wc_shipping_enabled() ) {
	$page_title    = apply_filters( 'woocommerce_my_account_my_address_title', esc_html__( 'My Addresses', 'stockholm' ) );
	$get_addresses = apply_filters( 'woocommerce_my_account_get_addresses', array(
		'billing'  => esc_html__( 'Billing address', 'stockholm' ),
		'shipping' => esc_html__( 'Shipping address', 'stockholm' ),
	), $customer_id );
} else {
	$page_title    = apply_filters( 'woocommerce_my_account_my_address_title', esc_html__( 'My Address', 'stockholm' ) );
	$get_addresses = apply_filters( 'woocommerce_my_account_get_addresses', array(
		'billing' => esc_html__( 'Billing address', 'stockholm' ),
	), $customer_id );
}
$oldcol = 1;
$col    = 1;
?>

<h2><?php echo wp_kses_post( $page_title ); ?></h2>

<p>
	<?php echo apply_filters( 'woocommerce_my_account_my_address_description', esc_html__( 'The following addresses will be used on the checkout page by default.', 'stockholm' ) ); ?>
</p>

<?php if ( ! wc_ship_to_billing_address_only() && wc_shipping_enabled() ) : ?>
	<div class="u-columns woocommerce-Addresses col2-set addresses">
<?php endif; ?>

<?php foreach ( $get_addresses as $name => $address_title ) : ?>
	<?php
		$address = wc_get_account_formatted_address( $name );
		$col     = $col * -1;
		$oldcol  = $oldcol * -1;
	?>
	<div class="u-column<?php echo esc_attr( $col ) < 0 ? 1 : 2; ?> col-<?php echo esc_attr( $oldcol ) < 0 ? 1 : 2; ?> woocommerce-Address">
		<header class="woocommerce-Address-title title">
			<h3><?php echo wp_kses_post( $address_title ); ?></h3>
			<a href="<?php echo esc_url( wc_get_endpoint_url( 'edit-address', $name ) ); ?>" class="edit button"><?php echo esc_attr( $address ) ? esc_html__( 'Edit', 'stockholm' ) : esc_html__( 'Add', 'stockholm' ); ?></a>
		</header>
		<address>
			<?php
				echo esc_attr( $address ) ? wp_kses_post( $address ) : esc_html__( 'You have not set up this type of address yet.', 'stockholm' );
			?>
		</address>
	</div>

<?php endforeach; ?>

<?php if ( ! wc_ship_to_billing_address_only() && wc_shipping_enabled() ) : ?>
	</div>
<?php
endif;
